@@ -1,7 +1,7 @@
 export smesolveProblem, smesolveEnsembleProblem, smesolve
 
-_smesolve_generate_state(u, dims, isoperket::Val{false}) = QuantumObject(vec2mat(u), type = Operator(), dims = dims)
-_smesolve_generate_state(u, dims, isoperket::Val{true}) = QuantumObject(u, type = OperatorKet(), dims = dims)
+_smesolve_generate_state(u, dims, ::Val{false}) = QuantumObject(vec2mat(u), type = Operator(), dims = dims)
+_smesolve_generate_state(u, dims, ::Val{true}) = QuantumObject(u, type = OperatorKet(), dims = dims)
 
 function _smesolve_update_coeff(u, p, t, op_vec)
     return 2 * real(dot(op_vec, u)) #this is Tr[Sn * ρ + ρ * Sn']
@@ -95,7 +95,9 @@ function smesolveProblem(
     sc_ops_isa_Qobj = sc_ops isa AbstractQuantumObject # We can avoid using non-diagonal noise if sc_ops is just an AbstractQuantumObject
 
     L_evo = _mesolve_make_L_QobjEvo(H, c_ops) + _mesolve_make_L_QobjEvo(nothing, sc_ops_list)
-    check_dimensions(L_evo, ψ0)
+    # Check Hilbert space compatibility using multiplication dimensions
+
+    check_mul_dimensions(L_evo, ψ0)
     dims = L_evo.dimensions
 
     T = _complex_float_type(Base.promote_eltype(L_evo, ψ0))
@@ -105,11 +107,11 @@ function smesolveProblem(
         to_dense(T, mat2vec(ket2dm(ψ0).data))
     end
 
-    sc_ops_evo_data = Tuple(map(get_data ∘ QobjEvo, sc_ops_list))
+    sc_ops_evo_data = map(get_data ∘ QobjEvo, sc_ops_list)
 
     K = cache_operator(get_data(L_evo), ρ0)
 
-    Id_op = IdentityOperator(prod(dims)^2)
+    Id_op = IdentityOperator(get_liouville_size(dims)[1])
     D_l = map(sc_ops_evo_data) do op
         # TODO: # Currently, we are assuming a time-independent MatrixOperator
         # Also, the u state may become non-hermitian, so Tr[Sn * ρ + ρ * Sn'] != real(Tr[Sn * ρ]) / 2
@@ -120,7 +122,7 @@ function smesolveProblem(
 
     tlist = _check_tlist(tlist, _float_type(T))
 
-    kwargs2 = _merge_saveat(tlist, e_ops, DEFAULT_SDE_SOLVER_OPTIONS; kwargs...)
+    kwargs2 = _merge_saveat(tlist, e_ops, default_sde_solver_options(T); kwargs...)
     kwargs3 = _merge_tstops(kwargs2, isconstant(K), tlist)
     kwargs4 = _generate_stochastic_kwargs(
         e_ops,
@@ -416,7 +418,7 @@ function smesolve(
     _expvals_sol_1 = _get_expvals(_sol_1, SaveFuncMESolve)
     _m_expvals_sol_1 = _get_m_expvals(_sol_1, SaveFuncSMESolve)
 
-    dims = ens_prob.dimensions
+    dims = ens_prob.dimensions.to
     _expvals_all =
         _expvals_sol_1 isa Nothing ? nothing : map(i -> _get_expvals(sol[:, i], SaveFuncMESolve), eachindex(sol))
     expvals_all = _expvals_all isa Nothing ? nothing : stack(_expvals_all, dims = 2) # Stack on dimension 2 to align with QuTiP
