@@ -36,14 +36,14 @@
     end
 
     @testset "kron" begin
-        # normal Space
+        # normal HilbertSpace
         D1 = 4
         D2 = 5
         dims_s = (D1, D2)
         ρ_s = rand_dm(dims_s)
         I_s = qeye(D1) ⊗ qeye(D2)
         size_s = prod(dims_s)
-        space_s = (Space(D1), Space(D2))
+        space_s = (HilbertSpace(D1), HilbertSpace(D2))
 
         # EnrSpace
         dims_enr = (2, 3, 2)
@@ -91,21 +91,26 @@
         ρ_tot = tensor(ρ_s, ρ_enr)
         opstring = sprint((t, s) -> show(t, "text/plain", s), ρ_tot)
         datastring = sprint((t, s) -> show(t, "text/plain", s), ρ_tot.data)
-        ρ_tot_dims = [dims_s..., dims_enr...]
+        ρ_tot_dims = ρ_tot.dims  # Now returns tuple format
         ρ_tot_size = size_s * size_enr
         ρ_tot_isherm = isherm(ρ_tot)
         @test opstring ==
             "\nQuantum Object:   type=Operator()   dims=$ρ_tot_dims   size=$((ρ_tot_size, ρ_tot_size))   ishermitian=$ρ_tot_isherm\n$datastring"
 
-        # use GeneralDimensions to do partial trace
-        new_dims1 = GeneralDimensions((Space(1), Space(1), space_enr), (Space(1), Space(1), space_enr))
+        # use non-square ProductDimensions to do partial trace
+        new_dims1 = ProductDimensions(
+            (HilbertSpace(1), HilbertSpace(1), space_enr),
+            (HilbertSpace(1), HilbertSpace(1), space_enr),
+        )
         ρ_enr_compound = Qobj(zeros(ComplexF64, size_enr, size_enr), dims = new_dims1)
         basis_list = [tensor(basis(D1, i), basis(D2, j)) for i in 0:(D1 - 1) for j in 0:(D2 - 1)]
         for b in basis_list
             ρ_enr_compound += tensor(b', I_enr) * ρ_tot * tensor(b, I_enr)
         end
-        new_dims2 =
-            GeneralDimensions((space_s..., Space(1), Space(1), Space(1)), (space_s..., Space(1), Space(1), Space(1)))
+        new_dims2 = ProductDimensions(
+            (space_s..., HilbertSpace(1), HilbertSpace(1), HilbertSpace(1)),
+            (space_s..., HilbertSpace(1), HilbertSpace(1), HilbertSpace(1)),
+        )
         ρ_s_compound = Qobj(zeros(ComplexF64, size_s, size_s), dims = new_dims2)
         basis_list = [enr_fock(space_enr, space_enr.idx2state[idx]) for idx in 1:space_enr.size]
         for b in basis_list
